@@ -34,8 +34,9 @@
 # ============================================================================
 #
 from dataclasses  import make_dataclass, dataclass
+from datetime     import datetime
 from os           import environ
-from typing import Dict
+from typing       import Dict
 
 from pyVersioning import SelfDescriptive
 
@@ -98,6 +99,9 @@ class CIService:
 	def getGitHash(self) -> str:
 		raise NotImplementedError()
 
+	def getCommitDate(self) -> datetime:
+		raise NotImplementedError()
+
 	def getGitBranch(self) -> str:
 		raise NotImplementedError()
 
